@@ -282,7 +282,9 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
  struct isoburn_toc_track **tracks;
  int num_sessions= 0, num_tracks= 0, track_count= 0, session_no= 0;
  char msg[80];
+ enum burn_disc_status s;
 
+ s= burn_disc_get_status(d);
  profile_name[0]= 0;
  ret= burn_disc_get_profile(d, &profile, profile_name);
  if(ret<=0)
@@ -339,7 +341,7 @@ static int isoburn_welcome_media(struct isoburn **o, struct burn_drive *d,
 
     /* >>> recognize unsuitable media (but allow read-only media) */;
 
-   if(readonly) {
+   if(readonly && s != BURN_DISC_EMPTY) {
      (*o)->fabricated_disc_status= BURN_DISC_FULL;
      /* This might be overwriteable media in a -ROM drive.
         Pitfall:
@@ -1634,7 +1636,7 @@ int isoburn_drive_set_msgs_submit(struct burn_drive *d,
 int isoburn_set_msc1(struct burn_drive *d, int adr_mode, char *adr_value,
                      int flag)
 {
- int ret, num_sessions, num_tracks, adr_num, i, j, total_tracks;
+ int ret, num_sessions= 0, num_tracks, adr_num, i, j, total_tracks;
  int lba, best_lba, size, re_valid= 0, track_count= 0;
  time_t start_time= 0, last_pacifier= 0, now;
  char volid[33], msg[160];
