@@ -16,7 +16,7 @@
 struct XorrisO; 
 
 
-#define Xorriso_program_versioN "0.5.0"
+#define Xorriso_program_versioN "0.5.2"
 #define Xorriso_program_patch_leveL ""
 
 
@@ -39,6 +39,20 @@ char *Xorriso__get_version_text(int flag);
 char *Xorriso__get_patch_level_text(int flag);
 
 
+/* Choose how Xorriso_startup_libraries() and the XorrisO object shall
+   prepare for eventual signals.
+   @param behavior Default is behavior 1.
+                   0= no own signal handling. The main application has to do
+                      that. Do not start burn runs without any handling !
+                   1= use libburn signal handler. Most time with action
+                      0. During writing, formatting, blanking: 0x30.
+                      Only usable with a single xorriso object.
+   @param flag     unused yet, submit 0
+   @return         <= 0 is error, >0 is success
+*/
+int Xorriso__preset_signal_behavior(int behavior, int flag);
+
+
 /* Mandatory call:
    Create a new xorriso object and tell it the program name to be used
    with messages and for decision of special behavior.
