@@ -50,10 +50,6 @@ struct SectorbitmaP;      /* Distiniction between valid and invalid sectors */
 /* maximum number of history lines to be reported with -status:long_history */
 #define Xorriso_status_history_maX 100
 
-/* <<< ??? */
-/* try to catch signals and ignore them during abort handling */
-#define Xorriso_abort_handler_defaulT (1|(2<<4))
-
 
 /** The list of startup file names */
 #define Xorriso_rc_nuM 4
@@ -475,6 +471,8 @@ struct XorrisO { /* the global context of xorriso */
 };
 
 
+int Xorriso__get_signal_behavior(int flag);
+
 int Xorriso_prepare_regex(struct XorrisO *xorriso, char *adr, int flag);
 
 int Xorriso_result(struct XorrisO *xorriso, int flag);
